pyFLTK 1.1.4 Programming Manual
Author: Written by Michael Sweet, Craig P. Earls, and Bill Spitzak

# Preface

This manual describes the Python wrappers for the Fast Light Tool Kit ("pyFLTK") version 1.1.2, a Python Graphical User Interface ("GUI") toolkit for UNIX, Microsoft Windows and MacOS. Each of the chapters in this manual is designed as a tutorial for using pyFLTK, while the appendices provide a convenient reference for all pyFLTK widgets, functions, and operating system interfaces.

This manual may be printed, modified, and/or used under the terms of the FLTK/pyFLTK license provided in Appendix H.

## Organization

This manual is organized into the following chapters and appendices:

- Chapter 1 - Introduction to FLTK/pyFLTK
- Chapter 2 - pyFLTK Basics
- Chapter 3 - Common Widgets and Attributes
- Chapter 4 - Designing a Simple Text Editor
- Chapter 5 - Drawing Things in pyFLTK
- Chapter 6 - Handling Events
- Chapter 7 - Extending and Adding Widgets
- Chapter 8 - Using OpenGL
- Appendix A - Reference Manual

Yet to come:

- Chapter 9 - Programming With FLUID
- Appendix D - GLUT Compatibility
- Appendix E - Forms Compatibility
- Appendix F - Operating System Issues
- Appendix G - Migrating from FLTK 1.0.x to FLTK 1.1.x
- Appendix H - Software License
- Appendix I - Example Source Code

## Conventions

The following typeface conventions are used in this manual:

- Function and constant names are shown in `bold courier type`
- Code samples and commands are shown in `regular courier type`

## Abbreviations

The following abbreviations are used in this manual:

X11
  The X Window System version 11.
Xlib
  The X Window System interface library.
WIN32
  The Microsoft Windows 32-bit Application Programmer's Interface.
MacOS
  The Apple Macintosh OS 8.6 and later, including OS X.

## Copyrights and Trademarks

FLTK is Copyright 1998-2006 by Bill Spitzak and others. Use and distribution of FLTK is governed by the GNU Library General Public License, located in Appendix H.

pyFLTK copyright 2003-2006 by Andreas Held and others. Use and distribution of pyFLTK is governed by the GNU Library General Public License, located in Appendix H.

UNIX is a registered trademark of the X Open Group, Inc. Microsoft and Windows are registered trademarks of Microsoft Corporation. OpenGL is a registered trademark of Silicon Graphics, Inc. Apple, Macintosh, MacOS, and Mac OS X are registered trademarks of Apple Computer, Inc.